/* -*- pftp-c -*- */
#ifndef TAB_COMP_H
#define TAB_COMP_H

#define TAB_COMMAND 0x1   // Check commands
#define TAB_DIRECTORY 0x2 // Check directories
#define TAB_FILE 0x04     // Check files
#define TAB_LOCAL 0x08    // Check dir/files on local
#define TAB_REMOTE 0x10   // Check dir/files on remote
#define TAB_SITENAME 0x20 // Check current open and saved names
#define TAB_LOADSITE 0x30 // Only check saved names

int tabPressed(char **line, size_t *line_pos, pftp_server_t ftp, 
	       unsigned int mask, int TERM_width);

#endif /* TAB_COMP_H */
